#
# spec file for package python-prompt_toolkit1
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         oldpython python
%bcond_without  test
Name:           python-prompt_toolkit1
Version:        1.0.18
Release:        bp154.1.24
Summary:        Library for building interactive command lines in Python
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/jonathanslenders/python-prompt-toolkit
Source:         https://files.pythonhosted.org/packages/source/p/prompt_toolkit/prompt_toolkit-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-six >= 1.9.0
Requires:       python-wcwidth
Recommends:     python-Pygments
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module wcwidth}
%endif
%ifpython2
Obsoletes:      %{oldpython}-python-prompt-toolkit < %{version}
Provides:       %{oldpython}-python-prompt-toolkit = %{version}
%endif
Provides:       python-prompt_toolkit = %{version}
Conflicts:      python-prompt_toolkit >= 2
%python_subpackages

%description
Prompt toolkit is a library for building interactive command
lines in Python.

%prep
%setup -q -n prompt_toolkit-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with test}
%check
# https://github.com/prompt-toolkit/python-prompt-toolkit/issues/1046
%pytest -k "not test_with_style"
%endif

%files %{python_files}
%license LICENSE
%doc AUTHORS.rst README.rst CHANGELOG
%{python_sitelib}/prompt_toolkit*

%changelog
* Tue Jan  7 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disabled test_with_style (gh#1046)
* Wed Dec 18 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 1.0.18
  * Handle HANDLE sizes correctly on windows
  * Fixes DeprecationWarning when trying to import collections.Mapping
* Fri Sep 28 2018 Todd R <toddrme2178@gmail.com>
- Create python2-only version 1 package.
  Python2 versions of IPython/Jupyter require prompt_toolkit 1.
  Python3 versions of IPython/Jupyter require prompt_toolkit 2.
  Once the IPython/Jupyter packages are updated this can be
  set to python2-only.
* Fri Jul 27 2018 jengelh@inai.de
- Trim filler wording from descriptions.
* Tue Jul 24 2018 mcepl@suse.com
- Downgrade back to 1.* line, 2.* breaks too many packages (all
  jupyter-ipython ones, for example)
* Sun Jul 22 2018 arun@gmx.de
- specfile:
  * remove devel from noarch
  * be more specific in %%files section
- update to version 2.0.4:
  * Bug fixes:
    + Fix render height for rendering full screen applications in
    Windows.
    + Fix in `TextArea`. Set `accept_handler` to `None` if not given.
    + Go to the beginning of the next line when enter is pressed in Vi
    navigation mode, and the buffer doesn't have an accept handler.
    + Fix the `default` argument of the `prompt` function when called
    multiple times.
    + Display decomposed multiwidth characters correctly.
    + Accept `history` in `prompt()` function again.
  * Backwards incompatible changes:
    + Renamed `PipeInput` to `PosixPipeInput`. Added `Win32PipeInput`
    and `create_input_pipe`.
    + Pass `buffer` argument to the `accept_handler` of `TextArea`.
  * New features:
    + Added `accept_default` argument to `prompt()`.
    + Make it easier to change the body/title of a Frame/Dialog.
    + Added `DynamicContainer`.
    + Added `merge_completers` for merging multiple completers
    together.
    + Add vt100 data to key presses in Windows.
    + Handle left/right key bindings in Vi block insert mode.
* Sat Jul 14 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 2.0.3:
  * Bug fixes:
    + Fix in 'x' and 'X' Vi key bindings. Correctly handle line
    endings and args.
    + Fixed off by one error in Vi line selection.
    + Fixed bugs in Vi block selection. Correctly handle lines that
    the selection doesn't cross.
    + Python 2 bugfix. Handle str/unicode correctly.
    + Handle option+left/right in iTerm.
- changes from version 2.0.2:
  * Bug fixes:
    + Python 3.7 support: correctly handle StopIteration in
    asynchronous generator.
    + Fixed off-by-one bug in Vi visual block mode.
    + Bugfix in TabsProcessor: handle situations when the cursor is at
    the end of the line.
- changes from version 2.0.1 + previous:
  * long list of changelog, see CHANGELOG in tar-ball for details.
* Fri May 18 2018 toddrme2178@gmail.com
- python-six also required for tests
* Tue Sep 19 2017 toddrme2178@gmail.com
- Update to version 1.0.15
  + Fixes:
  * Don't shuffle tasks in the event loop. This fixes an issue where lines
    printed from background threads were printed in a different order if
    `patch_stdout=True`.
  * Only consider the text before the cursor when activating history search.
  * Pressing escape should accept the search, this is closer to how readline works.
  * Enable autowrap again when required.
  + New features:
  * Add run_in_terminal option to disable cooked mode.
* Fri May  5 2017 toddrme2178@gmail.com
- Fix Provides/Obsoletes
* Mon Apr 24 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Mon Apr  3 2017 toddrme2178@gmail.com
- Fix source URL.
* Sat Apr  1 2017 toddrme2178@gmail.com
- Update to version 1.0.14
  + Rename package to python-prompt_toolkit
    ~ Upstream name change
  + See CHANGELOG file for changes
* Mon Jan 30 2017 rjschwei@suse.com
- Update to version 1.0.9 (bsc#1002895, FATE#321630)
  + Include in SLE 12
  + Rename package to python-python-prompt-toolkit
    ~ Upstream name change
  + See CHANGELOG file for changes
* Fri Aug 14 2015 toddrme2178@gmail.com
- Initial version
  + Version 0.46
